@@ -9,7 +9,7 @@ import (
 //go:embed scripts/omp.fish
 var fishInit string
 
-func (f Feature) Fish() Code {
+func (f Features) Fish() Code {
 	switch f {
 	case Transient:
 		return "set --global _omp_transient_prompt 1"
@@ -19,11 +19,13 @@ func (f Feature) Fish() Code {
 		return "set --global _omp_prompt_mark 1"
 	case Tooltips:
 		return "enable_poshtooltips"
+	case Streaming:
+		return "set --global _omp_enable_streaming 1"
 	case Upgrade:
 		return unixUpgrade
 	case Notice:
 		return unixNotice
-	case RPrompt, PoshGit, Azure, LineError, Jobs, CursorPositioning, Async:
+	case RPrompt, PoshGit, Azure, LineError, Jobs, CursorPositioning, Async, KeyHandlers:
 		fallthrough
 	default:
 		return ""
@@ -31,7 +33,7 @@ func (f Feature) Fish() Code {
 }
 
 func quoteFishStr(str string) string {
-	if len(str) == 0 {
+	if str == "" {
 		return "''"
 	}
 
